@@ -7,6 +7,7 @@
 #include <QFile>
 #include <QDir>
 #include <QList>
+#include <QTime>
 
 class QNetworkAccessManager;
 class QNetworkReply;
@@ -37,6 +38,7 @@ private slots:
     void parseVideoPage();
     void getVideoUrl(const QString &playerUrl);
     void performDownload(const QByteArray &videoUrl);
+    void updateProgress(qint64 bytesReceived, qint64 bytesTotal);
     void downloadFinished();
     void downloadReadyRead();
 
@@ -46,6 +48,7 @@ private:
     QHash<QString, int> dlMap;
     QFile output;
     QNetworkReply *downloadReply;
+    QTime downloadTime;
     bool downloading;
 
 signals:
@@ -55,7 +58,7 @@ signals:
     void downloadCompleted(const QString &filename);
     void downloadCancelled();
     void statusChanged(const QString &status);
-    void progressChanged(qint64 bytesReceived, qint64 bytesTotal);
+    void progressChanged(qint64 bytesReceived, qint64 bytesTotal, const QString &speed);
     void qualityChanged(const QString quality);
     void downloadingChanged();
 };
