@@ -1,6 +1,8 @@
 /* Video list functions */
 
 function appendVideoFeed() {
+    videoListModel.loading = true;
+
     var startIndex = videoList.count + 1;
     var doc = new XMLHttpRequest();
     doc.onreadystatechange = function() {
@@ -8,6 +10,8 @@ function appendVideoFeed() {
             var xml = doc.responseText;
             videoListModel.appendXml(xml);
         }
+
+        videoListModel.loading = false;
     }
     doc.open("GET", videoFeed + "&start-index=" + startIndex);
     if (YouTube.currentUser != "") {
